161,177 Commits over 4,597 Days - 1.46cph!

21 Days Ago
▋ ▆▋▇▉▊▅█ ▊▇▆▆▋█▅▋▆ ▊▊▉ ▋▊▄▄▇▉▆▆ ▅▄ ▊▌▍▋ ▍▇ ▉▉█▇▄▅▆▉ ▌▅▄▇█ ▇▋▄ ▍▉▇ ▅▆▋▄▄▇▌▇▉ ▋█▆▄▉▌▆▊▆▆▉ ▊█▉▅▆▉ ▌▌▋▇ ▉ ▌▇▇ ▋▄▋▉▇▄
21 Days Ago
Reviewed the 3P gun effects we spawn for distant shots: - Muzzle particles don't emit past 60m anymore, you only get the muzzle light and the sound - Shells aren't spawned past 15m Unchanged when using scopes and binoculars, the distances are stretched based on zoom scale
21 Days Ago
Item icon, delete some unused uzi fbx files at the root of the assets folder
21 Days Ago
merge from snowmobile_wheel_fix
21 Days Ago
Fixed snowmobile wheels jittering at standstill due to physics noise Before: https://files.facepunch.com/raul/2026/October/13_14-12-FrailCobra.mp4 After: https://files.facepunch.com/raul/2026/October/13_14-14-RedBlacknorwegianelkhound.mp4
21 Days Ago
Texture fixes
21 Days Ago
Send animal look direction in an RPC rather than with SendNetworkUpdate Animals with look animators were running network updates crazy often rather than just sending the look over This was especially bad with cows, wolfs, sheep and bulls Worst offender is cow at ~144 bytes per look update (network update). ~350 B/s per cow per player -> ~60 B/s
21 Days Ago
merge from main
21 Days Ago
Set all the gun firing effects warmed up amount accordingly Estimated +21MB vs main, still around -29MB overall after removing the 3900 useless thrown projectiles
21 Days Ago
Release pad run/crouch toggles when keyboard/mouse is used, so a pad latch can't carry into keyboard play
21 Days Ago
Various prefab fixes
21 Days Ago
Fix editor NRE debug
21 Days Ago
mag_drop_fixes -> main
21 Days Ago
Stop SpaceLR and M15 mags sticking to the bone
21 Days Ago
Gun attack effects can now be recycled before their tail sound finishes, means we only have to warm up half the amount we'd need to
21 Days Ago
Cleanup
21 Days Ago
merge from main
21 Days Ago
Skip the gamepad vehicle action set lookup when no Steam Input controller is active
21 Days Ago
Only send waterwheel network updates when its actually changed (at low speed) Saves ~76 B per skipped update per nearby player
21 Days Ago
Merge from main
21 Days Ago
Clear potential stale gamepad inventory cursors in edit mode
21 Days Ago
Tooltip bind lookup fix
21 Days Ago
Added replayInPlace to EffectRecycle, lets us flag effects that can be replayed in place instead of popping and retiring a pooled copy every time Applied to AK first and 3rd person shell eject effects for now, ~0.13ms -> ~0.04ms per shot Also means we'll only have to prewarm a handful of shell particle prefabs for all the guns
21 Days Ago
Adding dweller mace viewmodel rig
21 Days Ago
Merge from main
21 Days Ago
merge from main
21 Days Ago
Use Facepunch.Steamworks GetPngAnalogActionGlyph for stick/trigger glyphs, remove the now unnecessary hacky workaround
21 Days Ago
Merge from main
21 Days Ago
Fix motion vector pass being culled when ocean is present
21 Days Ago
Merge from main (actually latest this time)
21 Days Ago
Updating tattoo rig with updated mesh
21 Days Ago
Merge from main, and fix MapInterface marker conflict
21 Days Ago
Merge from render_pipeline_testing
21 Days Ago
Merge from render_pipeline_testing
21 Days Ago
Merge from fp_sw_glyph_fixes
21 Days Ago
Update Facepunch.Steamworks: fix Steam Input glyph origin buffer overflow, add GetPngAnalogActionGlyph, cache action set handles
21 Days Ago
Forward jump down animations for cow and sheep
21 Days Ago
Updating flail viewmodel rig
21 Days Ago
Rebind rendertarget to camera target after rendergraph and move SetupCameraProperties back
Rin
21 Days Ago
Handmade SMG damage Increased 20 > 21
21 Days Ago
▄▆▄▆▅█▋▍ ▉▋▆ ▍▉▇▅█▅▊ ▉█▍▄▇ ▆▍ ▉▇ █▆█ ▌▋▇▆▅▇▄▅▄▄ ▋▌▉▉▋ ▍▍ ▊▅▋▌ ▌▍█▆ ▄▍▌ ▇▉▅▇▊▄▌█ ▊▇▅▌▇▍▊█▊▅█▋▉▍▊▊▆▉ ▊▄▌ ▌▍▅▇▅▋▉ ▍█ ▅▉▊▇▆▊█▆▇▌▆█▋▅▉▅▇▇▍█▄▅█▌▉▋▇▄▉▆▆▅▉▆▍▍▄▅▋▄▅ ▍▆▋▋▇▄▋▉▅ ▌▇▉█▇▄▄▌ ▋▉▆█▋▄▊▅▌ ▉▆▊▅▅▊▌▆▅ ▌▊▄▆▊▊█▇ █▌▉ ▄▍▌▌▆█▅▋
21 Days Ago
Merge from car_spawning_prefill
21 Days Ago
Round up the amount of filled slots, so a 5 slot engine gets 3 prefilled instead of 2
21 Days Ago
Manifest update
21 Days Ago
Merge from main
21 Days Ago
Merge from prototype_draggable_markers Can now drag map markers on the map screen with MMB
21 Days Ago
▉▊▄▅▋▌ █▇▆▌▉█▍ ▍▄▉ ▄▄▇▋▆█▄
21 Days Ago
▉▄▊▊▌▅ ▉▇▍▅ ▄▌▊▍
21 Days Ago
Merge from terrain_watermap_test
21 Days Ago
Remove watermap texture2D creation on procedural map, saves ~89.5MB on 4k map